==> activity-center-api-3.4.5-sources.jar: cn/com/duiba/activity/center/api/dto/happycodenew/HappyCodeConfigDto.java <==
package cn.com.duiba.activity.center.api.dto.happycodenew;

import cn.com.duiba.api.enums.AppChannelTypeEnum;

import java.io.Serializable;

/**
 * @Author chenxiangge
 * @Date 2019/3/29
 */
public class HappyCodeConfigDto implements Serializable {
    private static final long serialVersionUID = -6878060932063516947L;

    private Long id;
    private Long appId;
    /**
     * 投放渠道
     */
    private AppChannelTypeEnum channelType;
    /**
     * 标题
     */
    private String title;
    /**
     * 规则
     */
    private String rule;
    /**
     * 是否展示中奖弹幕/轮播等
     */
    private Boolean showWinRecord;
    /**
     * 分享标题
     */
    private String shareTitle;
    /**
     * 分享副标题
     */
    private String shareSubTitle;
    /**
     * 分享图片
     */
    private String sharePic;
    /**
     * banner图
     */
    private String bannerImage;
    /**
     * 缩略图
     */
    private String smallImage;
    /**
     * 皮肤配置
     */
    private String skinConfig;
    /**
     * 小程序授权地址
     */
    private String authorizeUrl;

    private String qrCode;

    public String getQrCode() {
        return qrCode;
    }

    public void setQrCode(String qrCode) {
        this.qrCode = qrCode;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public Boolean getShowWinRecord() {
        return showWinRecord;
    }

    public void setShowWinRecord(Boolean showWinRecord) {
        this.showWinRecord = showWinRecord;
    }

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareSubTitle() {
        return shareSubTitle;
    }

    public void setShareSubTitle(String shareSubTitle) {
        this.shareSubTitle = shareSubTitle;
    }

    public String getSharePic() {
        return sharePic;
    }

    public void setSharePic(String sharePic) {
        this.sharePic = sharePic;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getSkinConfig() {
        return skinConfig;
    }

    public void setSkinConfig(String skinConfig) {
        this.skinConfig = skinConfig;
    }

    public AppChannelTypeEnum getChannelType() {
        return channelType;
    }

    public void setChannelType(AppChannelTypeEnum channelType) {
        this.channelType = channelType;
    }

    public String getAuthorizeUrl() {
        return authorizeUrl;
    }

    public void setAuthorizeUrl(String authorizeUrl) {
        this.authorizeUrl = authorizeUrl;
    }
}

==> activity-center-api-3.5.73-sources.jar: cn/com/duiba/activity/center/api/dto/happycodenew/HappyCodeConfigDto.java <==
package cn.com.duiba.activity.center.api.dto.happycodenew;

import cn.com.duiba.api.enums.AppChannelTypeEnum;

import java.io.Serializable;

/**
 * @Author chenxiangge
 * @Date 2019/3/29
 */
public class HappyCodeConfigDto implements Serializable {
    private static final long serialVersionUID = -6878060932063516947L;

    private Long id;
    private Long appId;
    /**
     * 投放渠道
     */
    private AppChannelTypeEnum channelType;
    /**
     * 标题
     */
    private String title;
    /**
     * 规则
     */
    private String rule;
    /**
     * 是否展示中奖弹幕/轮播等
     */
    private Boolean showWinRecord;

    /**
     * 分享开关
     */
    private Boolean shareSwitch;
    /**
     * 分享标题
     */
    private String shareTitle;
    /**
     * 分享副标题
     */
    private String shareSubTitle;
    /**
     * 分享图片
     */
    private String sharePic;
    /**
     * banner图
     */
    private String bannerImage;
    /**
     * 缩略图
     */
    private String smallImage;
    /**
     * 皮肤配置
     */
    private String skinConfig;
    /**
     * 小程序授权地址
     */
    private String authorizeUrl;

    private String qrCode;
    /**
     * 是否微信授权分享
     */
    private Boolean shareWeiXinSwitch;

    /**
     * 微信免登地址
     */
    private String shareWeiXinUrl;

    public String getShareWeiXinUrl() {
        return shareWeiXinUrl;
    }

    public void setShareWeiXinUrl(String shareWeiXinUrl) {
        this.shareWeiXinUrl = shareWeiXinUrl;
    }

    public Boolean  getShareWeiXinSwitch() {
        return shareWeiXinSwitch;
    }

    public void setShareWeiXinSwitch(Boolean shareWeiXinSwitch) {
        this.shareWeiXinSwitch = shareWeiXinSwitch;
    }

    public String getQrCode() {
        return qrCode;
    }

    public void setQrCode(String qrCode) {
        this.qrCode = qrCode;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public Boolean getShowWinRecord() {
        return showWinRecord;
    }

    public void setShowWinRecord(Boolean showWinRecord) {
        this.showWinRecord = showWinRecord;
    }

    public Boolean getShareSwitch() {
        return shareSwitch;
    }

    public void setShareSwitch(Boolean shareSwitch) {
        this.shareSwitch = shareSwitch;
    }

    public String getShareTitle() {
        return shareTitle;
    }

    public void setShareTitle(String shareTitle) {
        this.shareTitle = shareTitle;
    }

    public String getShareSubTitle() {
        return shareSubTitle;
    }

    public void setShareSubTitle(String shareSubTitle) {
        this.shareSubTitle = shareSubTitle;
    }

    public String getSharePic() {
        return sharePic;
    }

    public void setSharePic(String sharePic) {
        this.sharePic = sharePic;
    }

    public String getBannerImage() {
        return bannerImage;
    }

    public void setBannerImage(String bannerImage) {
        this.bannerImage = bannerImage;
    }

    public String getSmallImage() {
        return smallImage;
    }

    public void setSmallImage(String smallImage) {
        this.smallImage = smallImage;
    }

    public String getSkinConfig() {
        return skinConfig;
    }

    public void setSkinConfig(String skinConfig) {
        this.skinConfig = skinConfig;
    }

    public AppChannelTypeEnum getChannelType() {
        return channelType;
    }

    public void setChannelType(AppChannelTypeEnum channelType) {
        this.channelType = channelType;
    }

    public String getAuthorizeUrl() {
        return authorizeUrl;
    }

    public void setAuthorizeUrl(String authorizeUrl) {
        this.authorizeUrl = authorizeUrl;
    }
}
